#!/usr/bin/env python
"""Django's command-line utility for administrative tasks."""
import os
import sys
settings = 'empty_my_fridge.cpanel.settings'
try:
    import empty_my_fridge.manage
except ModuleNotFoundError:
    settings = 'cpanel.settings'

def main():
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', settings)
    try:
        #from django.core.management import execute_from_command_line
        from django.core.management import call_command
        from django.core.wsgi import get_wsgi_application
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc
    #execute_from_command_line(sys.argv)
    application = get_wsgi_application()
    call_command('runserver', '127.0.0.1:8000')
    


if __name__ == '__main__':
    main()
   
