class ActivityPage:
    def __init__(self):
        self.activity = None

    def get_activity_page(self):
        return self.activity

    def set_activity_page(self, activity):
        self.activity = activity       